Learn R Programming

episheet (version 0.4.0)

tolbutamide: tolbutamide data - chapter 15-1, p260

Description

Age-specific comparison of death from all causes for Tolbutamide and placebo treatment groups, University Group Diabetes Program (1970)

Usage

tolbutamide

Arguments

Format

An object of class data.frame with 409 rows and 3 columns.

Details

@format A dataframe with 409 observations and 3 variables

tolbutamide

Given Tolbutamide (1) or placebo (0)

dead

Died (1) or surviving (0)

age

Less than 55 (<55) or 55 and over (ge55)